[rkward/frameworks] rkward: KAction -> QAction

Thomas Friedrichsmeier thomas.friedrichsmeier at ruhr-uni-bochum.de
Wed Jun 3 12:19:08 UTC 2015


Git commit d676a65abff075c184631d92df7c745ea93de4dc by Thomas Friedrichsmeier.
Committed on 03/06/2015 at 12:17.
Pushed by tfry into branch 'frameworks'.

KAction -> QAction
(kde-dev-scripts/kf5/convert-kaction.pl + some sed on the whitespace)

M  +1    -1    rkward/dataeditor/twintable.cpp
M  +13   -13   rkward/dataeditor/twintable.h
M  +1    -1    rkward/misc/editlabelsdialog.cpp
M  +11   -11   rkward/misc/rkstandardactions.cpp
M  +6    -6    rkward/misc/rkstandardactions.h
M  +1    -1    rkward/plugin/rkcomponentcontext.cpp
M  +1    -1    rkward/plugin/rkcomponentcontext.h
M  +1    -1    rkward/plugin/rkcomponentmap.cpp
M  +1    -1    rkward/plugin/rkcomponentmap.h
M  +3    -3    rkward/plugin/rkmatrixinput.cpp
M  +1    -1    rkward/plugin/rkstandardcomponentgui.cpp
M  +3    -3    rkward/rkconsole.cpp
M  +7    -7    rkward/rkconsole.h
M  +3    -3    rkward/rkward.cpp
M  +18   -18   rkward/rkward.h
M  +2    -2    rkward/windows/rkcommandeditorwindow.cpp
M  +8    -8    rkward/windows/rkcommandeditorwindow.h
M  +1    -1    rkward/windows/rkcommandlog.cpp
M  +1    -1    rkward/windows/rkcommandlog.h
M  +3    -3    rkward/windows/rkhtmlwindow.cpp
M  +3    -3    rkward/windows/rkmdiwindow.cpp
M  +1    -1    rkward/windows/rktoplevelwindowgui.cpp
M  +3    -3    rkward/windows/rktoplevelwindowgui.h
M  +8    -8    rkward/windows/rkwindowcatcher.cpp
M  +10   -10   rkward/windows/rkwindowcatcher.h
M  +3    -3    rkward/windows/rkworkplace.cpp
M  +4    -4    rkward/windows/rkworkplace.h
M  +3    -3    rkward/windows/rkworkplaceview.cpp
M  +3    -3    rkward/windows/rkworkplaceview.h

http://commits.kde.org/rkward/d676a65abff075c184631d92df7c745ea93de4dc

diff --git a/rkward/dataeditor/twintable.cpp b/rkward/dataeditor/twintable.cpp
index 317fc4f..5d1c61b 100644
--- a/rkward/dataeditor/twintable.cpp
+++ b/rkward/dataeditor/twintable.cpp
@@ -18,7 +18,7 @@
 #include "twintable.h"
 
 #include <klocale.h>
-#include <kaction.h>
+#include <QAction>
 #include <kactioncollection.h>
 #include <kxmlguifactory.h>
 #include <kmessagebox.h>
diff --git a/rkward/dataeditor/twintable.h b/rkward/dataeditor/twintable.h
index 7ecc94f..6a803b2 100644
--- a/rkward/dataeditor/twintable.h
+++ b/rkward/dataeditor/twintable.h
@@ -30,7 +30,7 @@
 class TwinTableMember;
 class RKVarEditModel;
 class QActionGroup;
-class KAction;
+class QAction;
 
 /**
   *@author Thomas Friedrichsmeier
@@ -92,18 +92,18 @@ protected:
 	TwinTableMember* metaview;
 	TwinTableMember* dataview;
 
-	KAction* action_insert_col_left;
-	KAction* action_delete_col;
-	KAction* action_insert_row_above;
-	KAction* action_delete_row;
-	KAction* action_delete_rows;
-	KAction* action_enable_editing;
-	KAction* action_show_rownames;
-	KAction* editCut;
-	KAction* editCopy;
-	KAction* editPaste;
-	KAction* editPasteToSelection;
-	KAction* editPasteToTable;
+	QAction* action_insert_col_left;
+	QAction* action_delete_col;
+	QAction* action_insert_row_above;
+	QAction* action_delete_row;
+	QAction* action_delete_rows;
+	QAction* action_enable_editing;
+	QAction* action_show_rownames;
+	QAction* editCut;
+	QAction* editCopy;
+	QAction* editPaste;
+	QAction* editPasteToSelection;
+	QAction* editPasteToTable;
 
 	QActionGroup* edit_actions;
 
diff --git a/rkward/misc/editlabelsdialog.cpp b/rkward/misc/editlabelsdialog.cpp
index 72182c1..6e00246 100644
--- a/rkward/misc/editlabelsdialog.cpp
+++ b/rkward/misc/editlabelsdialog.cpp
@@ -18,7 +18,7 @@
 
 #include <klocale.h>
 #include <kdialog.h>
-#include <kaction.h>
+#include <QAction>
 #include <kactioncollection.h>
 #include <kvbox.h>
 
diff --git a/rkward/misc/rkstandardactions.cpp b/rkward/misc/rkstandardactions.cpp
index ec37e3b..383cf8b 100644
--- a/rkward/misc/rkstandardactions.cpp
+++ b/rkward/misc/rkstandardactions.cpp
@@ -19,7 +19,7 @@
 
 #include <klocale.h>
 #include <kactioncollection.h>
-#include <kaction.h>
+#include <QAction>
 
 #include "rkstandardicons.h"
 #include "rkspecialactions.h"
@@ -27,28 +27,28 @@
 
 #include "../debug.h"
 
-KAction* RKStandardActions::copyLinesToOutput (RKMDIWindow *window, const QObject *receiver, const char *member) {
+QAction* RKStandardActions::copyLinesToOutput (RKMDIWindow *window, const QObject *receiver, const char *member) {
 	RK_TRACE (MISC);
 
-	KAction* ret = window->standardActionCollection ()->addAction ("copy_lines_to_output", receiver, member);
+	QAction* ret = window->standardActionCollection ()->addAction ("copy_lines_to_output", receiver, member);
 	ret->setText (i18n ("Copy lines to output"));
 	return ret;
 }
 
-KAction* RKStandardActions::pasteSpecial (RKMDIWindow *window, const QObject *receiver, const char *member) {
+QAction* RKStandardActions::pasteSpecial (RKMDIWindow *window, const QObject *receiver, const char *member) {
 	RK_TRACE (MISC);
 
-	KAction* ret = new RKPasteSpecialAction (window->standardActionCollection ());
+	QAction* ret = new RKPasteSpecialAction (window->standardActionCollection ());
 	window->standardActionCollection ()->addAction ("paste_special", ret);
 	ret->connect (ret, SIGNAL (pasteText(QString)), receiver, member);
 	ret->setShortcut (Qt::ShiftModifier + Qt::ControlModifier + Qt::Key_V);
 	return ret;
 }
 
-KAction* RKStandardActions::runCurrent (RKMDIWindow *window, const QObject *receiver, const char *member, bool current_or_line) {
+QAction* RKStandardActions::runCurrent (RKMDIWindow *window, const QObject *receiver, const char *member, bool current_or_line) {
 	RK_TRACE (MISC);
 
-	KAction* ret = window->standardActionCollection ()->addAction ("run_current", receiver, member);
+	QAction* ret = window->standardActionCollection ()->addAction ("run_current", receiver, member);
 	if (current_or_line) {
 		ret->setText (i18n ("Run line / selection"));
 		ret->setStatusTip (i18n ("Runs the current selection (if any) or the current line (if there is no selection)"));
@@ -61,20 +61,20 @@ KAction* RKStandardActions::runCurrent (RKMDIWindow *window, const QObject *rece
 	return ret;
 }
 
-KAction* RKStandardActions::runAll (RKMDIWindow *window, const QObject *receiver, const char *member) {
+QAction* RKStandardActions::runAll (RKMDIWindow *window, const QObject *receiver, const char *member) {
 	RK_TRACE (MISC);
 
-	KAction* ret = window->standardActionCollection ()->addAction ("run_all", receiver, member);
+	QAction* ret = window->standardActionCollection ()->addAction ("run_all", receiver, member);
 	ret->setText (i18n ("Run all"));
 	ret->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionRunAll));
 	ret->setShortcut (KShortcut (Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Return, Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Enter));
 	return ret;
 }
 
-KAction* RKStandardActions::functionHelp (RKMDIWindow *window, const QObject *receiver, const char *member) {
+QAction* RKStandardActions::functionHelp (RKMDIWindow *window, const QObject *receiver, const char *member) {
 	RK_TRACE (MISC);
 
-	KAction* ret = window->standardActionCollection ()->addAction ("function_reference", receiver, member);
+	QAction* ret = window->standardActionCollection ()->addAction ("function_reference", receiver, member);
 	ret->setText (i18n ("&Function reference"));
 	ret->setShortcut (Qt::Key_F2);
 	return ret;
diff --git a/rkward/misc/rkstandardactions.h b/rkward/misc/rkstandardactions.h
index a9071ff..353b4d4 100644
--- a/rkward/misc/rkstandardactions.h
+++ b/rkward/misc/rkstandardactions.h
@@ -18,7 +18,7 @@
 #ifndef RKSTANDARDACTIONS_H
 #define RKSTANDARDACTIONS_H
 
-class KAction;
+class QAction;
 class QString;
 class QObject;
 class RKMDIWindow;
@@ -27,15 +27,15 @@ class RKMDIWindow;
 
 @author Thomas Friedrichsmeier */
 namespace RKStandardActions {
-	KAction *copyLinesToOutput (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
+	QAction *copyLinesToOutput (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
 /** Allows special pasting modes for script windows.
 @param member needs to have the signature void fun (const QString&). */
-	KAction* pasteSpecial (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
+	QAction* pasteSpecial (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
 
-	KAction* runCurrent (RKMDIWindow *window, const QObject *receiver=0, const char *member=0, bool current_or_line=false);
-	KAction* runAll (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
+	QAction* runCurrent (RKMDIWindow *window, const QObject *receiver=0, const char *member=0, bool current_or_line=false);
+	QAction* runAll (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
 
-	KAction* functionHelp (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
+	QAction* functionHelp (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
 };
 
 #endif
diff --git a/rkward/plugin/rkcomponentcontext.cpp b/rkward/plugin/rkcomponentcontext.cpp
index 562e8c3..94a328a 100644
--- a/rkward/plugin/rkcomponentcontext.cpp
+++ b/rkward/plugin/rkcomponentcontext.cpp
@@ -17,7 +17,7 @@
 
 #include "rkcomponentcontext.h"
 
-#include <kaction.h>
+#include <QAction>
 #include <kactioncollection.h>
 
 #include "rkstandardcomponent.h"
diff --git a/rkward/plugin/rkcomponentcontext.h b/rkward/plugin/rkcomponentcontext.h
index 184c192..5b59fd9 100644
--- a/rkward/plugin/rkcomponentcontext.h
+++ b/rkward/plugin/rkcomponentcontext.h
@@ -47,7 +47,7 @@ protected:
 	RKContextHandler (QObject *parent, const QDomDocument &gui_xml, const QString &id);
 /** desctructor. Should be called automatically, as this is QObject */
 	~RKContextHandler ();
-/** add a KAction to the context. To be called from RKContext::makeContextHandler(). */
+/** add a QAction to the context. To be called from RKContext::makeContextHandler(). */
 	void addAction (const QString &id, RKComponentHandle *handle);
 private slots:
 /** slot to handle plugin activation */
diff --git a/rkward/plugin/rkcomponentmap.cpp b/rkward/plugin/rkcomponentmap.cpp
index 0b49c75..e45d9cb 100644
--- a/rkward/plugin/rkcomponentmap.cpp
+++ b/rkward/plugin/rkcomponentmap.cpp
@@ -717,7 +717,7 @@ void RKComponentMap::addedEntry (const QString &id, RKComponentHandle *handle) {
 	RK_TRACE (PLUGIN);
 
 	handle->setAccessible (true);
-	KAction *action = actionCollection ()->addAction (id, this, SLOT (activateComponent()));
+	QAction *action = actionCollection ()->addAction (id, this, SLOT (activateComponent()));
 	action->setText (handle->getLabel ());
 	action->setShortcutConfigurable (true);
 }
diff --git a/rkward/plugin/rkcomponentmap.h b/rkward/plugin/rkcomponentmap.h
index e41314a..bf9b229 100644
--- a/rkward/plugin/rkcomponentmap.h
+++ b/rkward/plugin/rkcomponentmap.h
@@ -161,7 +161,7 @@ protected:
 /** reset the xml file */
 	void clearGUIDescription ();
 
-/** an entry was added to the menu(s) somewhere. Reimplement, if you want to e.g. create a KAction for this */
+/** an entry was added to the menu(s) somewhere. Reimplement, if you want to e.g. create a QAction for this */
 	virtual void addedEntry (const QString & /* id */, RKComponentHandle * /* handle */) {};
 
 /** The generated XML GUI description in KDEs ui.rc format */
diff --git a/rkward/plugin/rkmatrixinput.cpp b/rkward/plugin/rkmatrixinput.cpp
index a5213bc..60293a8 100644
--- a/rkward/plugin/rkmatrixinput.cpp
+++ b/rkward/plugin/rkmatrixinput.cpp
@@ -105,11 +105,11 @@ RKMatrixInput::RKMatrixInput (const QDomElement& element, RKComponent* parent_co
 	}
 
 	// define standard actions
-	KAction *cut = KStandardAction::cut (this, SLOT (cut()), this);
+	QAction *cut = KStandardAction::cut (this, SLOT (cut()), this);
 	display->addAction (cut);
-	KAction *copy = KStandardAction::copy (this, SLOT (copy()), this);
+	QAction *copy = KStandardAction::copy (this, SLOT (copy()), this);
 	display->addAction (copy);
-	KAction *paste = KStandardAction::paste (this, SLOT (paste()), this);
+	QAction *paste = KStandardAction::paste (this, SLOT (paste()), this);
 	display->addAction (paste);
 	display->setContextMenuPolicy (Qt::ActionsContextMenu);
 
diff --git a/rkward/plugin/rkstandardcomponentgui.cpp b/rkward/plugin/rkstandardcomponentgui.cpp
index ed65f81..a8317e7 100644
--- a/rkward/plugin/rkstandardcomponentgui.cpp
+++ b/rkward/plugin/rkstandardcomponentgui.cpp
@@ -18,7 +18,7 @@
 #include "rkstandardcomponentgui.h"
 
 #include <klocale.h>
-#include <kaction.h>
+#include <QAction>
 #include <kactioncollection.h>
 #include <kurl.h>
 #include <kvbox.h>
diff --git a/rkward/rkconsole.cpp b/rkward/rkconsole.cpp
index ee519a2..4b31f95 100644
--- a/rkward/rkconsole.cpp
+++ b/rkward/rkconsole.cpp
@@ -30,7 +30,7 @@
 #include <QVBoxLayout>
 
 #include <klocale.h>
-#include <kaction.h>
+#include <QAction>
 #include <kactioncollection.h>
 #include <kconfig.h>
 #include <kapplication.h>
@@ -169,7 +169,7 @@ QAction* RKConsole::addProxyAction (const QString& actionName, const QString& la
 	}
 
 	if (found) {
-		QAction* ret = new KAction (getPart ());
+		QAction* ret = new QAction (getPart ());
 		if (label.isEmpty ()) ret->setText (found->text ());
 		else ret->setText (label);
 		ret->setIcon (found->icon ());
@@ -922,7 +922,7 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 	addProxyAction ("view_inc_font_sizes");
 	addProxyAction ("view_dec_font_sizes");
 
-	KAction *action = ac->addAction ("loadhistory", this, SLOT (userLoadHistory()));
+	QAction *action = ac->addAction ("loadhistory", this, SLOT (userLoadHistory()));
 	action->setText (i18n ("Import command history..."));
 	action = ac->addAction ("savehistory", this, SLOT (userSaveHistory()));
 	action->setText (i18n ("Export command history..."));
diff --git a/rkward/rkconsole.h b/rkward/rkconsole.h
index 55446c0..ad30145 100644
--- a/rkward/rkconsole.h
+++ b/rkward/rkconsole.h
@@ -31,7 +31,7 @@
 class QEvent;
 class QKeyEvent;
 class QStringList;
-class KAction;
+class QAction;
 class RCommand;
 class KActionCollection;
 class RKConsolePart;
@@ -135,12 +135,12 @@ friend class RKConsolePart;
 
 	bool tab_key_pressed_before;
 
-	KAction* context_help_action;
-	KAction* run_selection_action;
-	KAction* interrupt_command_action;
-	KAction* copy_commands_action;
-	KAction* copy_literal_action;
-	KAction* paste_action;
+	QAction* context_help_action;
+	QAction* run_selection_action;
+	QAction* interrupt_command_action;
+	QAction* copy_commands_action;
+	QAction* copy_literal_action;
+	QAction* paste_action;
 
 	KActionCollection *kate_edit_actions;
 	void triggerEditAction (QString name);
diff --git a/rkward/rkward.cpp b/rkward/rkward.cpp
index 01cae3c..71186f0 100644
--- a/rkward/rkward.cpp
+++ b/rkward/rkward.cpp
@@ -417,7 +417,7 @@ void RKWardMainWindow::initToolViewsAndR () {
 
 void RKWardMainWindow::initActions() {  
 	RK_TRACE (APP);
-	KAction *action;
+	QAction *action;
 
 	// TODO: is there a way to insert actions between standard actions without having to give all standard actions custom ids?
 	new_data_frame = actionCollection ()->addAction ("new_data_frame", this, SLOT (slotNewDataFrame()));
@@ -521,7 +521,7 @@ void RKWardMainWindow::initActions() {
 	open_any_action->addAction (fileOpen);
 	open_any_action->addAction (fileOpenRecent);
 	open_any_action->addSeparator ();
-	proxy_import = new KAction (i18n ("Import"), this);
+	proxy_import = new QAction (i18n ("Import"), this);
 	open_any_action->addAction (proxy_import);
 
 	KActionMenu* new_any_action = new KActionMenu (KIcon ("document-new"), i18n ("Create..."), this);
@@ -535,7 +535,7 @@ void RKWardMainWindow::initActions() {
 	save_any_action->setDelayed (false);
 	actionCollection ()->addAction ("save_any", save_any_action);
 
-	proxy_export = new KAction (i18n ("Export"), this);
+	proxy_export = new QAction (i18n ("Export"), this);
 	save_any_action->addAction (fileSaveWorkspace);
 	save_any_action->addAction (fileSaveWorkspaceAs);
 	save_any_action->addSeparator ();
diff --git a/rkward/windows/rkcommandeditorwindow.cpp b/rkward/windows/rkcommandeditorwindow.cpp
index dc12fce..1759fdc 100644
--- a/rkward/windows/rkcommandeditorwindow.cpp
+++ b/rkward/windows/rkcommandeditorwindow.cpp
@@ -41,7 +41,7 @@
 #include <kmenu.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <kaction.h>
+#include <QAction>
 #include <kstandardaction.h>
 #include <klibloader.h>
 #include <kactioncollection.h>
@@ -214,7 +214,7 @@ void RKCommandEditorWindow::initializeActions (KActionCollection* ac) {
 	action_run_all = RKStandardActions::runAll (this, this, SLOT (runAll()));
 	action_run_current = RKStandardActions::runCurrent (this, this, SLOT (runCurrent()), true);
 	// NOTE: enter_and_submit is not currently added to the menu
-	KAction *action = ac->addAction ("enter_and_submit", this, SLOT (enterAndSubmit()));
+	QAction *action = ac->addAction ("enter_and_submit", this, SLOT (enterAndSubmit()));
 	action->setText (i18n ("Insert line break and run"));
 	action->setShortcuts (KShortcut (Qt::AltModifier + Qt::Key_Return, Qt::AltModifier + Qt::Key_Enter));
 
diff --git a/rkward/windows/rkcommandeditorwindow.h b/rkward/windows/rkcommandeditorwindow.h
index 9222651..2e3461b 100644
--- a/rkward/windows/rkcommandeditorwindow.h
+++ b/rkward/windows/rkcommandeditorwindow.h
@@ -42,7 +42,7 @@ class QEvent;
 class QCloseEvent;
 class QFrame;
 class QLabel;
-class KAction;
+class QAction;
 class QAction;
 class KActionMenu;
 class RKCommandEditorWindow;
@@ -268,9 +268,9 @@ private:
 #endif
 		bool active;
 		KTextEditor::Attribute::Ptr attribute;
-		KAction* mark;
-		KAction* unmark;
-		KAction* run;
+		QAction* mark;
+		QAction* unmark;
+		QAction* run;
 	};
 	QVector<BlockRecord> block_records;
 	void initBlocks ();
@@ -283,12 +283,12 @@ private:
 	KActionMenu* actionmenu_unmark_block;
 	KActionMenu* actionmenu_run_block;
 
-	KAction* action_run_all;
-	KAction* action_run_current;
+	QAction* action_run_all;
+	QAction* action_run_current;
 
-	KAction* action_setwd_to_script;
+	QAction* action_setwd_to_script;
 
-	KAction* action_help_function;
+	QAction* action_help_function;
 
 	KUrl previous_autosave_url;
 	QTimer* autosave_timer;
diff --git a/rkward/windows/rkcommandlog.cpp b/rkward/windows/rkcommandlog.cpp
index e4e3bba..6248adf 100644
--- a/rkward/windows/rkcommandlog.cpp
+++ b/rkward/windows/rkcommandlog.cpp
@@ -264,7 +264,7 @@ void RKCommandLogView::selectAll () {
 /////////////////////// BEGIN RKCommandLogPart ////////////////////////
 
 #include <kxmlguifactory.h>
-#include <kaction.h>
+#include <QAction>
 
 RKCommandLogPart::RKCommandLogPart (RKCommandLog *for_log) : KParts::Part (0) {
 	RK_TRACE (APP);
diff --git a/rkward/windows/rkcommandlog.h b/rkward/windows/rkcommandlog.h
index 3786d4b..f426086 100644
--- a/rkward/windows/rkcommandlog.h
+++ b/rkward/windows/rkcommandlog.h
@@ -90,7 +90,7 @@ protected:
 
 #include <kparts/part.h>
 
-class KAction;
+class QAction;
 
 /** Provides a part interface for the RKCommandLog */
 class RKCommandLogPart : public KParts::Part {
diff --git a/rkward/windows/rkhtmlwindow.cpp b/rkward/windows/rkhtmlwindow.cpp
index eb5905e..f406b98 100644
--- a/rkward/windows/rkhtmlwindow.cpp
+++ b/rkward/windows/rkhtmlwindow.cpp
@@ -582,9 +582,9 @@ void RKHTMLWindowPart::initActions () {
 
 	// common actions
 	actionCollection ()->addAction (KStandardAction::Copy, "copy", window->view->pageAction (QWebPage::Copy), SLOT (trigger()));
-	QAction* zoom_in = actionCollection ()->addAction ("zoom_in", new KAction (KIcon ("zoom-in"), i18n ("Zoom In"), this));
+	QAction* zoom_in = actionCollection ()->addAction ("zoom_in", new QAction (KIcon ("zoom-in"), i18n ("Zoom In"), this));
 	connect (zoom_in, SIGNAL(triggered(bool)), window, SLOT (zoomIn()));
-	QAction* zoom_out = actionCollection ()->addAction ("zoom_out", new KAction (KIcon ("zoom-out"), i18n ("Zoom Out"), this));
+	QAction* zoom_out = actionCollection ()->addAction ("zoom_out", new QAction (KIcon ("zoom-out"), i18n ("Zoom Out"), this));
 	connect (zoom_out, SIGNAL(triggered(bool)), window, SLOT (zoomOut()));
 	actionCollection ()->addAction (KStandardAction::SelectAll, "select_all", window->view->pageAction (QWebPage::SelectAll), SLOT (trigger()));
 	// unfortunately, this will only affect the default encoding, not necessarily the "real" encoding
@@ -615,7 +615,7 @@ void RKHTMLWindowPart::initActions () {
 	outputRefresh->setIcon (KIcon ("view-refresh"));
 
 	actionCollection ()->addAction (KStandardAction::Find, "find", window->findbar, SLOT (activate()));
-	KAction* findAhead = actionCollection ()->addAction ("find_ahead", new KAction (i18n ("Find as you type"), this));
+	QAction* findAhead = actionCollection ()->addAction ("find_ahead", new QAction (i18n ("Find as you type"), this));
 	findAhead->setShortcut ('/');
 	connect (findAhead, SIGNAL (triggered(bool)), window->findbar, SLOT (activate()));
 	actionCollection ()->addAction (KStandardAction::FindNext, "find_next", window->findbar, SLOT (forward()));;
diff --git a/rkward/windows/rkmdiwindow.cpp b/rkward/windows/rkmdiwindow.cpp
index aa3dd31..b5a5784 100644
--- a/rkward/windows/rkmdiwindow.cpp
+++ b/rkward/windows/rkmdiwindow.cpp
@@ -27,7 +27,7 @@
 #include <kxmlguifactory.h>
 #include <kactioncollection.h>
 #include <klocale.h>
-#include <kaction.h>
+#include <QAction>
 
 #include "rkworkplace.h"
 #include "rkworkplaceview.h"
@@ -295,11 +295,11 @@ void RKMDIWindow::setMetaInfo (const QString& _generic_window_name, const QStrin
 	settings_page = _settings_page;
 
 	if (!help_url.isEmpty ()) {
-		KAction *action = standardActionCollection ()->addAction ("window_help", this, SLOT (showWindowHelp()));
+		QAction *action = standardActionCollection ()->addAction ("window_help", this, SLOT (showWindowHelp()));
 		action->setText (i18n ("Help on %1", generic_window_name));
 	}
 	if (settings_page != RKSettings::NoPage) {
-		KAction *action = standardActionCollection ()->addAction ("window_configure", this, SLOT (showWindowSettings()));
+		QAction *action = standardActionCollection ()->addAction ("window_configure", this, SLOT (showWindowSettings()));
 		action->setText (i18n ("Configure %1", generic_window_name));
 	}
 }
diff --git a/rkward/windows/rktoplevelwindowgui.cpp b/rkward/windows/rktoplevelwindowgui.cpp
index 8408e3b..b649c08 100644
--- a/rkward/windows/rktoplevelwindowgui.cpp
+++ b/rkward/windows/rktoplevelwindowgui.cpp
@@ -82,7 +82,7 @@ RKTopLevelWindowGUI::RKTopLevelWindowGUI (KXmlGuiWindow *for_window) : QObject (
 	next_action->setIcon (QIcon (RKCommonFunctions::getRKWardDataDir () + "icons/window_forward.png"));
 	next_action->setShortcut (Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Tab);
 
-	KAction *action;
+	QAction *action;
 	foreach (const RKToolWindowList::ToolWindowRepresentation& rep, RKToolWindowList::registeredToolWindows ()) {
 		action = actionCollection ()->addAction ("window_show_" + rep.id, this, SLOT (toggleToolView()));
 		action->setText (i18n ("Show/Hide %1", rep.window->shortCaption ()));
diff --git a/rkward/windows/rktoplevelwindowgui.h b/rkward/windows/rktoplevelwindowgui.h
index a255a1a..8218c49 100644
--- a/rkward/windows/rktoplevelwindowgui.h
+++ b/rkward/windows/rktoplevelwindowgui.h
@@ -24,7 +24,7 @@
 
 class KXmlGuiWindow;
 class RKMDIWindow;
-class KAction;
+class QAction;
 
 /** represents the common portions of the GUI for top level windows: The help menu, and the windows menu */
 class RKTopLevelWindowGUI : public QObject, public KXMLGUIClient {
@@ -64,8 +64,8 @@ private slots:
 	void nextWindow ();
 private:
 	KXmlGuiWindow *for_window;
-	KAction *prev_action;
-	KAction *next_action;
+	QAction *prev_action;
+	QAction *next_action;
 	void toggleToolView (RKMDIWindow *tool_window);
 };
 
diff --git a/rkward/windows/rkwindowcatcher.cpp b/rkward/windows/rkwindowcatcher.cpp
index fcdcf75..638fe5c 100644
--- a/rkward/windows/rkwindowcatcher.cpp
+++ b/rkward/windows/rkwindowcatcher.cpp
@@ -651,19 +651,19 @@ RKCaughtX11WindowPart::RKCaughtX11WindowPart (RKCaughtX11Window *window) : KPart
 	action = actionCollection ()->addAction ("plot_prev", window, SLOT (previousPlot()));
  	action->setText (i18n ("Previous plot"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionMoveLeft));
-	window->plot_prev_action = (KAction*) action;
+	window->plot_prev_action = (QAction *) action;
 	action = actionCollection ()->addAction ("plot_first", window, SLOT (firstPlot()));
  	action->setText (i18n ("First plot"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionMoveFirst));
-	window->plot_first_action = (KAction*) action;
+	window->plot_first_action = (QAction *) action;
 	action = actionCollection ()->addAction ("plot_next", window, SLOT (nextPlot()));
  	action->setText (i18n ("Next plot"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionMoveRight));
-	window->plot_next_action = (KAction*) action;
+	window->plot_next_action = (QAction *) action;
 	action = actionCollection ()->addAction ("plot_last", window, SLOT (lastPlot()));
  	action->setText (i18n ("Last plot"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionMoveLast));
-	window->plot_last_action = (KAction*) action;
+	window->plot_last_action = (QAction *) action;
 	action = window->plot_list_action = new KSelectAction (i18n ("Go to plot"), 0);
 	window->plot_list_action->setToolBarMode (KSelectAction::MenuMode);
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionListPlots));
@@ -673,19 +673,19 @@ RKCaughtX11WindowPart::RKCaughtX11WindowPart (RKCaughtX11Window *window) : KPart
 	action = actionCollection ()->addAction ("plot_force_append", window, SLOT (forceAppendCurrentPlot()));
  	action->setText (i18n ("Append this plot"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionSnapshot));
-	window->plot_force_append_action = (KAction*) action;
+	window->plot_force_append_action = (QAction *) action;
 	action = actionCollection ()->addAction ("plot_remove", window, SLOT (removeCurrentPlot()));
  	action->setText (i18n ("Remove this plot"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionRemovePlot));
-	window->plot_remove_action = (KAction*) action;
+	window->plot_remove_action = (QAction *) action;
 
 	action = actionCollection ()->addAction ("plot_clear_history", window, SLOT (clearHistory()));
-	window->plot_clear_history_action = (KAction*) action;
+	window->plot_clear_history_action = (QAction *) action;
  	action->setText (i18n ("Clear history"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionClear));
 
 	action = actionCollection ()->addAction ("plot_properties", window, SLOT (showPlotInfo()));
-	window->plot_properties_action = (KAction*) action;
+	window->plot_properties_action = (QAction *) action;
 	action->setText (i18n ("Plot properties"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionDocumentInfo));
 
diff --git a/rkward/windows/rkwindowcatcher.h b/rkward/windows/rkwindowcatcher.h
index e119558..47bcab1 100644
--- a/rkward/windows/rkwindowcatcher.h
+++ b/rkward/windows/rkwindowcatcher.h
@@ -86,7 +86,7 @@ private:
 
 class RKCaughtX11WindowPart;
 class KToggleAction;
-class KAction;
+class QAction;
 class KSelectAction;
 class QXEmbedCopy;
 class QScrollArea;
@@ -191,16 +191,16 @@ private:
 
 	bool dynamic_size;
 	KToggleAction *dynamic_size_action;
-	KAction *plot_prev_action;
-	KAction *plot_next_action;
-	KAction *plot_first_action;
-	KAction *plot_last_action;
-	KAction *plot_force_append_action;
-	KAction *plot_remove_action;
-	KAction *plot_clear_history_action;
-	KAction *plot_properties_action;
+	QAction *plot_prev_action;
+	QAction *plot_next_action;
+	QAction *plot_first_action;
+	QAction *plot_last_action;
+	QAction *plot_force_append_action;
+	QAction *plot_remove_action;
+	QAction *plot_clear_history_action;
+	QAction *plot_properties_action;
 	KSelectAction *plot_list_action;
-	KAction *stop_interaction;
+	QAction *stop_interaction;
 
 	KPassivePopup* status_popup;
 	RCommand* status_change_command;
diff --git a/rkward/windows/rkworkplace.cpp b/rkward/windows/rkworkplace.cpp
index 5562ff7..a95e9d4 100644
--- a/rkward/windows/rkworkplace.cpp
+++ b/rkward/windows/rkworkplace.cpp
@@ -836,14 +836,14 @@ void RKMDIWindowHistory::windowActivated (RKMDIWindow *window) {
 	updateSwitcher ();
 }
 
-void RKMDIWindowHistory::next (KAction* prev_action, KAction *next_action) {
+void RKMDIWindowHistory::next (QAction* prev_action, QAction *next_action) {
 	RK_TRACE (APP);
 
 	if (recent_windows.isEmpty ()) return;
 	getSwitcher (prev_action, next_action)->next ();
 }
 
-void RKMDIWindowHistory::prev (KAction* prev_action, KAction *next_action) {
+void RKMDIWindowHistory::prev (QAction* prev_action, QAction *next_action) {
 	RK_TRACE (APP);
 
 	if (recent_windows.isEmpty ()) return;
@@ -872,7 +872,7 @@ void RKMDIWindowHistory::removeWindow (RKMDIWindow *window) {
 	updateSwitcher ();
 }
 
-RKMDIWindowHistoryWidget* RKMDIWindowHistory::getSwitcher (KAction* prev_action, KAction *next_action) {
+RKMDIWindowHistoryWidget* RKMDIWindowHistory::getSwitcher (QAction* prev_action, QAction *next_action) {
 	RK_TRACE (APP);
 
 	if (switcher) return switcher;
diff --git a/rkward/windows/rkworkplace.h b/rkward/windows/rkworkplace.h
index 6e97652..7bfabf0 100644
--- a/rkward/windows/rkworkplace.h
+++ b/rkward/windows/rkworkplace.h
@@ -33,7 +33,7 @@ class RCommandChain;
 class RKWorkplaceView;
 class RKEditor;
 class KActionCollection;
-class KAction;
+class QAction;
 class RKToolWindowBar;
 class RKMDIWindowHistoryWidget;
 class RKGraphicsDevice;
@@ -51,8 +51,8 @@ public:
 /** pops the last window from the list, if it matches the given pointer */
 	void popLastWindow (RKMDIWindow *match);
 	RKMDIWindow *previousDocumentWindow ();
-	void next (KAction *prev_action, KAction *next_action);
-	void prev (KAction *prev_action, KAction *next_action);
+	void next (QAction *prev_action, QAction *next_action);
+	void prev (QAction *prev_action, QAction *next_action);
 public slots:
 	void windowActivated (RKMDIWindow *window);
 private slots:
@@ -61,7 +61,7 @@ private:
 	void updateSwitcher ();
 	QList<RKMDIWindow *> recent_windows;
 	RKMDIWindowHistoryWidget *switcher;
-	RKMDIWindowHistoryWidget *getSwitcher (KAction *prev_action, KAction *next_action);
+	RKMDIWindowHistoryWidget *getSwitcher (QAction *prev_action, QAction *next_action);
 };
 
 /** This class (only one instance will probably be around) keeps track of which windows are opened in the workplace, which are detached, etc. Also it is responsible for creating and manipulating those windows.
diff --git a/rkward/windows/rkworkplaceview.cpp b/rkward/windows/rkworkplaceview.cpp
index 005eb22..9a03235 100644
--- a/rkward/windows/rkworkplaceview.cpp
+++ b/rkward/windows/rkworkplaceview.cpp
@@ -21,7 +21,7 @@
 #include <klocale.h>
 #include <kshortcut.h>
 #include <kactioncollection.h>
-#include <kaction.h>
+#include <QAction>
 #include <kicon.h>
 #include <kdeversion.h>
 #include <kacceleratormanager.h>
@@ -80,11 +80,11 @@ RKWorkplaceView::~RKWorkplaceView () {
 void RKWorkplaceView::initActions (KActionCollection *ac, const char *id_left, const char *id_right) {
 	RK_TRACE (APP);
 
-	action_page_left = (KAction*) ac->addAction (id_left, this, SLOT (pageLeft()));
+	action_page_left = (QAction *) ac->addAction (id_left, this, SLOT (pageLeft()));
 	action_page_left->setText (i18n ("Window Left"));
 	action_page_left->setShortcut (KShortcut (Qt::ControlModifier + Qt::Key_Less, Qt::ControlModifier + Qt::Key_Comma));
 
-	action_page_right = (KAction*) ac->addAction (id_right, this, SLOT (pageRight()));
+	action_page_right = (QAction *) ac->addAction (id_right, this, SLOT (pageRight()));
 	action_page_right->setText (i18n ("Window Right"));
 	action_page_right->setShortcut (KShortcut (Qt::ControlModifier + Qt::Key_Greater, Qt::ControlModifier + Qt::Key_Period));
 
diff --git a/rkward/windows/rkworkplaceview.h b/rkward/windows/rkworkplaceview.h
index 4b7dcd2..7bae77b 100644
--- a/rkward/windows/rkworkplaceview.h
+++ b/rkward/windows/rkworkplaceview.h
@@ -21,7 +21,7 @@
 #include <ktabwidget.h>
 
 class RKMDIWindow;
-class KAction;
+class QAction;
 class KActionCollection;
 
 /** This is mostly a KTabWidget with some extras such as updating the caption, a context menu, etc.
@@ -82,8 +82,8 @@ private slots:
 private:
 	void updateActions ();
 
-	KAction *action_page_left;
-	KAction *action_page_right;
+	QAction *action_page_left;
+	QAction *action_page_right;
 };
 
 #endif



More information about the rkward-tracker mailing list
diff --git a/rkward/rkward.h b/rkward/rkward.h
index 828ada7..a5de6ab 100644
--- a/rkward/rkward.h
+++ b/rkward/rkward.h
@@ -19,7 +19,7 @@
 #define RKWARD_H
 
 #include <kapplication.h>
-#include <kaction.h>
+#include <QAction>
 #include <kurl.h>
 #include <kparts/mainwindow.h>
 
@@ -144,31 +144,31 @@ private:
 	QLabel* statusbar_ready;
 	KParts::PartManager *part_manager;
 
-	// KAction pointers to enable/disable actions
-	KAction* fileOpen;
+	// QAction pointers to enable/disable actions
+	QAction* fileOpen;
 	KRecentFilesAction* fileOpenRecent;
 	
-	KAction* fileOpenWorkspace;
+	QAction* fileOpenWorkspace;
 	KRecentFilesAction* fileOpenRecentWorkspace;
-	KAction* fileSaveWorkspace;
-	KAction* fileSaveWorkspaceAs;
-	KAction* fileQuit;
-	KAction* interrupt_all_commands;
-	KAction* close_all_editors;
-	KAction* new_data_frame;
-	KAction* new_command_editor;
-
-	KAction* window_close_all;
-	KAction* window_detach;
+	QAction* fileSaveWorkspace;
+	QAction* fileSaveWorkspaceAs;
+	QAction* fileQuit;
+	QAction* interrupt_all_commands;
+	QAction* close_all_editors;
+	QAction* new_data_frame;
+	QAction* new_command_editor;
+
+	QAction* window_close_all;
+	QAction* window_detach;
 	
-	KAction* configure;
+	QAction* configure;
 
 	/** used so that if the menu is empty, there is a note in it, explaining that fact */
-	KAction* edit_menu_dummy;
+	QAction* edit_menu_dummy;
 	/** used so that if the menu is empty, there is a note in it, explaining that fact */
-	KAction* view_menu_dummy;
+	QAction* view_menu_dummy;
 
-	KAction* proxy_export, *proxy_import;
+	QAction* proxy_export, *proxy_import;
 	KActionMenu* save_any_action;
 	QAction* save_actions_plug_point;
 	QList<QPointer <QAction> > plugged_save_actions;